@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Mojo::Script;
 
@@ -16,11 +16,9 @@ require IO::File;
 use Mojo::ByteStream;
 use Mojo::Template;
 
-__PACKAGE__->attr(
-    description => (chained => 1, default => 'No description.'));
-__PACKAGE__->attr(quiet => (chained => 1, default => 0));
-__PACKAGE__->attr(
-    renderer => (chained => 1, default => sub { Mojo::Template->new }));
+__PACKAGE__->attr(description => (default => 'No description.'));
+__PACKAGE__->attr(quiet       => (default => 0));
+__PACKAGE__->attr(renderer    => (default => sub { Mojo::Template->new }));
 
 sub chmod_file {
     my ($self, $path, $mod) = @_;
