@@ -20,11 +20,11 @@ sub error {
     return $self->{error} = $message;
 }
 
-sub has_error { return defined shift->{error} }
+sub has_error { defined shift->{error} }
 
-sub is_done { return shift->state eq 'done' }
+sub is_done { shift->state eq 'done' }
 
-sub is_finished { return shift->is_state(qw/done done_with_leftovers error/) }
+sub is_finished { shift->is_state(qw/done done_with_leftovers error/) }
 
 sub is_state {
     my ($self, @states) = @_;
