@@ -11,8 +11,8 @@ use Mojo::ByteStream;
 use Mojo::Loader;
 use Mojo::Loader::Exception;
 
-__PACKAGE__->attr(disallow =>
-      (default => sub { [qw/new app attr meta render req res stash/] }));
+__PACKAGE__->attr(
+    disallow => (default => sub { [qw/new app attr render req res stash/] }));
 __PACKAGE__->attr('namespace');
 
 # Hey. What kind of party is this? There's no booze and only one hooker.
