@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Test::Mojo::Server;
 
@@ -13,14 +13,9 @@ use IO::Socket::INET;
 use Mojo::Home;
 use Test::Builder::Module;
 
-__PACKAGE__->attr([qw/command pid port/] => (chained => 1));
-__PACKAGE__->attr(
-    home => (
-        chained => 1,
-        default => sub { Mojo::Home->new }
-    )
-);
-__PACKAGE__->attr(timeout => (chained => 1, default => 5));
+__PACKAGE__->attr([qw/command pid port/]);
+__PACKAGE__->attr(home => (default => sub { Mojo::Home->new }));
+__PACKAGE__->attr(timeout => (default => 5));
 
 # Hello, my name is Barney Gumble, and I'm an alcoholic.
 # Mr Gumble, this is a girl scouts meeting.
@@ -238,8 +233,8 @@ sub _start_server {
 sub _stop_server {
     my $self = shift;
 
-    # Kill server
-    kill 'INT', $self->pid;
+    # Kill server portable
+    kill $^O eq 'MSWin32' ? 'KILL' : 'INT', $self->pid;
     close $self->{_server};
     $self->pid(undef);
     undef $self->{_server};
